package com.huimv.wine.ws;

import com.fasterxml.jackson.databind.util.BeanUtil;
import com.huimv.wine.entity.Device;
import com.huimv.wine.entity.vo.WsEvent;
import com.huimv.wine.mapper.DeviceMapper;
import com.huimv.wine.utils.SpringContextUtil;
import com.huimv.wine.utils.WebsocketSellerUtil;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;
import org.springframework.web.socket.handler.TextWebSocketHandler;

import javax.websocket.*;
import javax.websocket.server.PathParam;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.Date;

/**
 * websocket接口处理类
 */
@Component
@ServerEndpoint(value = "/seller/{seq}")
public class SellerController extends TextWebSocketHandler {
    /**
     * 连接事件，加入注解
     */
    @OnOpen
    public void onOpen(@PathParam(value = "seq") String seq, Session session) {
        String message = "[" + seq + "]加入聊天室！！";
        System.out.println(message);

        //需要用这种方式注入
        DeviceMapper deviceMapper = SpringContextUtil.getBean(DeviceMapper.class);
        Device device =  deviceMapper.getByDeviceId(seq);
        if (ObjectUtils.isEmpty(device)){
            device = new Device();
            device.setId(seq);
            deviceMapper.insert(device);
        }else {
            device.setLast(new Date());
            deviceMapper.updateDeviceById(device);
        }

        // 添加到session的映射关系中
        WebsocketSellerUtil.addSession(seq, session);

        infoOfDevice(session,deviceMapper);
    }

    /**
     * 连接事件，加入注解
     * 用户断开链接
     */
    @OnClose
    public void onClose(@PathParam(value = "seq") String seq, Session session) {

        // 删除映射关系
        WebsocketSellerUtil.removeSession(seq);

//        WebsocketSellerUtil.sendMessageForAll(message);
    }


    @OnMessage
    public void onMessage( Session session, String message) {
//        RemoteEndpoint.Async asyncRemote = session.getAsyncRemote();

        System.out.println(message);
        //下发数据
//        asyncRemote.sendText(message);

        WebsocketSellerUtil.sendMessage(session,message);
        // 直接广播

    }

    /**
     * 处理用户活连接异常
     *
     * @param session
     * @param throwable
     */
    @OnError
    public void onError(Session session, Throwable throwable) {
        try {
            session.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
        throwable.printStackTrace();
    }

    public void   infoOfDevice(Session session, DeviceMapper deviceMapper) {


    }

}
